Learn R Programming

MRCV (version 0.1-0)

farmer3: Kansas Farmer Data of Bilder and Loughin (2007)

Description

Survey of 279 Kansas farmers conducted by the Department of Animal Sciences at Kansas State University. Data are provided for only three of the survey questions.

Usage

farmer3

Arguments

format

The data frame contains 279 rows and the following 12 columns: Columns 1-3 correspond to the response categories for the question "Which of the following do you test your swine waste for?" Binary responses (1 = Yes, 0 = No) are provided for each category.
  • W1
{Nitrogen} W2 {Phosphorous} W3 {Salt}

itemize

  • Z1

item

  • Y2
  • Y3
  • Y4
  • Z2
  • Z3
  • Z4
  • Z5

source

Bilder, C. and Loughin, T. (2007) Modeling association between two or more categorical variables that allow for multiple category choices. Communications in Statistics--Theory and Methods, 36, 433--451.